==> e107-0.7.20.tbz: www/e107/e107_languages/English/lan_user_extended.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_languages/English/lan_user_extended.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/
define("UE_LAN_1", "Text Box");
define("UE_LAN_2", "Radio Buttons");
define("UE_LAN_3", "Drop-Down Menu");
define("UE_LAN_4", "DB Table Field");
define("UE_LAN_5", "Textarea");
define("UE_LAN_6", "Integer");
define("UE_LAN_7", "Date");
define("UE_LAN_8", "Language");

define("UE_LAN_9", "Name");
define("UE_LAN_10", "Type");
define("UE_LAN_11", "Use");

define("UE_LAN_HIDE", "Hide from users");

define("UE_LAN_LOCATION", "Location");
define("UE_LAN_LOCATION_DESC", "User location");
define("UE_LAN_AIM", "AIM Address");
define("UE_LAN_AIM_DESC", "AIM Address");
define("UE_LAN_ICQ", "ICQ Number");
define("UE_LAN_ICQ_DESC", "ICQ Number");
define("UE_LAN_YAHOO", "Yahoo! Address");
define("UE_LAN_YAHOO_DESC", "Yahoo! Address");
define("UE_LAN_MSN", "MSN");
define("UE_LAN_MSN_DESC", "MSN Address");
define("UE_LAN_HOMEPAGE", "Homepage");
define("UE_LAN_HOMEPAGE_DESC", "User homepage (url)");
define("UE_LAN_BIRTHDAY", "Birthday");
define("UE_LAN_BIRTHDAY_DESC", "Birthday");
define("UE_LAN_LANGUAGE", "Language");
define("UE_LAN_LANGUAGE_DESC", "User Language");
define("UE_LAN_COUNTRY", "Country");
define("UE_LAN_COUNTRY_DESC", "User Country (includes db table)");

define("LAN_UE_FAIL_HOMEPAGE", "Invalid entry for home page setting");

?>

==> e107-1.0.3.tbz: www/e107/e107_languages/English/lan_user_extended.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_languages/English/lan_user_extended.php $
|     $Revision: 11678 $
|     $Id: lan_user_extended.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/
define("UE_LAN_1", "Text Box");
define("UE_LAN_2", "Radio Buttons");
define("UE_LAN_3", "Drop-Down Menu");
define("UE_LAN_4", "DB Table Field");
define("UE_LAN_5", "Textarea");
define("UE_LAN_6", "Integer");
define("UE_LAN_7", "Date");
define("UE_LAN_8", "Language");

define("UE_LAN_9", "Name");
define("UE_LAN_10", "Type");
define("UE_LAN_11", "Use");

define("UE_LAN_HIDE", "Hide from users");

define("UE_LAN_LOCATION", "Location");
define("UE_LAN_LOCATION_DESC", "User location");
define("UE_LAN_AIM", "AIM Address");
define("UE_LAN_AIM_DESC", "AIM Address");
define("UE_LAN_ICQ", "ICQ Number");
define("UE_LAN_ICQ_DESC", "ICQ Number");
define("UE_LAN_YAHOO", "Yahoo! Address");
define("UE_LAN_YAHOO_DESC", "Yahoo! Address");
define("UE_LAN_MSN", "MSN");
define("UE_LAN_MSN_DESC", "MSN Address");
define("UE_LAN_HOMEPAGE", "Homepage");
define("UE_LAN_HOMEPAGE_DESC", "User homepage (url)");
define("UE_LAN_BIRTHDAY", "Birthday");
define("UE_LAN_BIRTHDAY_DESC", "Birthday");
define("UE_LAN_LANGUAGE", "Language");
define("UE_LAN_LANGUAGE_DESC", "User Language");
define("UE_LAN_COUNTRY", "Country");
define("UE_LAN_COUNTRY_DESC", "User Country (includes db table)");

define("LAN_UE_FAIL_HOMEPAGE", "Invalid entry for home page setting");

?>
